jacinle.utils.meta
==================

.. automodule:: jacinle.utils.meta

   
   
   .. rubric:: Module attributes

   .. autosummary::
   
      UNSET
   
   

   
   
   .. rubric:: Classes

   .. autosummary::
      :template: class.rst
   
      Clock
   
   

   
   
   .. rubric:: Functions

   .. autosummary::
   
      assert_instance
      assert_none
      assert_notnone
      cond_with
      cond_with_group
      decorator_with_optional_args
      dict_deep_keys
      dict_deep_kv
      dict_deep_update
      filter_exec
      first
      first_n
      gofor
      make_dummy_func
      map_exec
      map_exec_method
      merge_iterable
      method2func
      notnone_property
      repr_from_str
      run_once
      stmap
      synchronized
      timeout
      try_run
   
   

   
   
   








.. rubric:: Class Clock
.. autoclass:: Clock
   :members:
   :show-inheritance:
   :inherited-members: str, list, set, frozenset, dict, Module
   :undoc-members:
   :special-members: __call__, __add__, __mul__, __div__, __floordiv__







.. rubric:: Functions

.. autofunction:: assert_instance

.. autofunction:: assert_none

.. autofunction:: assert_notnone

.. autofunction:: cond_with

.. autofunction:: cond_with_group

.. autofunction:: decorator_with_optional_args

.. autofunction:: dict_deep_keys

.. autofunction:: dict_deep_kv

.. autofunction:: dict_deep_update

.. autofunction:: filter_exec

.. autofunction:: first

.. autofunction:: first_n

.. autofunction:: gofor

.. autofunction:: make_dummy_func

.. autofunction:: map_exec

.. autofunction:: map_exec_method

.. autofunction:: merge_iterable

.. autofunction:: method2func

.. autofunction:: notnone_property

.. autofunction:: repr_from_str

.. autofunction:: run_once

.. autofunction:: stmap

.. autofunction:: synchronized

.. autofunction:: timeout

.. autofunction:: try_run


